import React, {Component} from 'react';
import {
  Text,
  View,
  ScrollView,
  TextInput,
  StyleSheet,
  Button,
  findNodeHandle,
} from 'react-native';
import {SafeAreaView} from 'react-navigation';
import {KeyboardAwareScrollView} from 'react-native-keyboard-aware-scroll-view';

export default class AddTagScreen extends Component {
  constructor(props) {
    super(props);
    this.state = {textKey: null, textValue: null};
  }

  inputFocused(refName) {
    setTimeout(() => {
      let scrollResponder = this.refs.scrollView.getScrollResponder();
      scrollResponder.scrollResponderScrollNativeHandleToKeyboard(
        findNodeHandle(this.refs[refName]),
        100,
        true,
      );
    }, 50);
  }

  render() {
    const {navigation} = this.props;
    const onDone = navigation.getParam('returnData');
    const itemKey = navigation.getParam('itemKey');
    const itemValue = navigation.getParam('itemValue');
    console.log('key ' + itemKey + itemValue);
    if (itemKey != null && itemValue != null) {
      this.state.textKey = itemKey;
      this.state.textValue = itemValue;
      navigation.setParams({itemKey: null, itemValue: null}); // clear
    }
    return (
      <SafeAreaView
        forceInset={{bottom: 'always'}}
        style={{flex: 1}}
        onPress={() => {
          Keyboard.dismiss();
        }}>
        <KeyboardAwareScrollView
          ref="scrollView"
          contentContainerStyle={styles.scrollStyle}>
          <TextInput
            style={styles.textInputStyle}
            placeholder={'key'}
            placeholderTextColor={'#999'}
            value={this.state.textKey}
            onChangeText={key => {
              this.setState({textKey: key});
            }}
          />
          <TextInput
            style={styles.textInputStyle}
            placeholder={'value'}
            placeholderTextColor={'#999'}
            value={this.state.textValue}
            onChangeText={value => {
              this.setState({textValue: value});
            }}
          />
          <Button
            onPress={() => {
              if (this.state.textKey != null && this.state.textValue != null) {
                navigation.goBack();
                onDone(this.state.textKey, this.state.textValue);
              }
            }}
            title="Add Tag"
          />
        </KeyboardAwareScrollView>
      </SafeAreaView>
    );
  }
}

const styles = StyleSheet.create({
  container: {
    flex: 1,
  },
  scrollStyle: {
    flexGrow: 1,
  },
  textInputStyle: {
    marginHorizontal: 15,
    marginVertical: 30,
    height: 40,
    color: '#000',
    fontSize: 14,
    textAlign: 'left',
    textAlignVertical: 'center',
    overflow: 'hidden',
    justifyContent: 'center',
    alignItems: 'center',
    flexWrap: 'wrap',
    paddingLeft: 10,
    borderRadius: 5,
    borderColor: '#d5d5d5',
    borderWidth: 0.5,
    backgroundColor: '#f5f5f5',
  },
});
