import React from 'react';
import {
  Button,
  Image,
  View,
  Text,
  Platform,
  DeviceEventEmitter,
} from 'react-native';
import {createAppContainer, SafeAreaView} from 'react-navigation';
import {createStackNavigator, HeaderBackButton} from 'react-navigation-stack';
import ToggleSwitch from 'toggle-switch-react-native';
import {StyleSheet, TouchableOpacity} from 'react-native';
import DialogInput from 'react-native-dialog-input';
import TagsScreen from './TagsScreen';
import AddTagScreen from './AddTagScreen';
import Toast from 'react-native-toast-message';
import {NativeEventEmitter, NativeModules} from 'react-native';
import appConfig from './app.json';
import PushNotification from 'react-native-push-notification';

var Appear2mee = NativeModules.RNAppear2mee;
const Appear2meeEmitter = new NativeEventEmitter(Appear2mee);
PushNotification.requestPermissions();

Appear2meeEmitter.addListener(Appear2mee.notificationAccepted, keyValues => {
  if (!keyValues) {
    keyValues = {};
  }
  DeviceEventEmitter.emit(
    'Toast',
    'Notification Accepted:' + JSON.stringify(keyValues),
    true,
  );
});

Appear2meeEmitter.addListener(Appear2mee.notificationDismissed, keyValues => {
  if (!keyValues) {
    keyValues = {};
  }
  DeviceEventEmitter.emit(
    'Toast',
    'Notification Dismissed:' + JSON.stringify(keyValues),
    true,
  );
});

/*
// Default settings, only if you are changing something
var appear2meeDefaultSettings = {};
appear2meeDefaultSettings[Appear2mee.notificationDismiss] = 'Dismiss';
// ios 12 will use custom Action.
appear2meeDefaultSettings[Appear2mee.notificationAccep] = 'OK';
// ios 12 will use touch image/video to play.
appear2meeDefaultSettings[Appear2mee.notificationPlay] = 'Play';
appear2meeDefaultSettings[Appear2mee.messageExpired] =
  'Sorry, opportunity missed!';

// Position of face in app.
appear2meeDefaultSettings[Appear2mee.faceHeadPosition] =
  Appear2mee.faceHeadTopLeft;
appear2meeDefaultSettings[Appear2mee.faceShouldersPosition] =
  Appear2mee.faceShouldersRight;

// Color of app display background when showing an in app notification.
appear2meeDefaultSettings[Appear2mee.displayBackgroundColor] = '#00000099';
appear2meeDefaultSettings[Appear2mee.faceDisplayBackgroundColor] = '#00000033';

// Color of face background, only used with RNAppear2mee.faceHeadCenter setting for RNAppear2mee.faceHeadPosition
appear2meeDefaultSettings[Appear2mee.faceCenterBackgroundColor] = '#ffffffff';

// Notification sounds. Defaults are built into the SDK.
// If you need to change uncomment.
//appear2meeDefaultSettings[Appear2mee.faceNotificationSound]="tothepoint.aiff";
//appear2meeDefaultSettings[Appear2mee.notificationSound]="slowspringboard.aiff";

// iOS Content Extension background images. Defaults are built into the SDK.
// These need to be stored in the Content Extension bundle.
// If you need to change uncomment.
//appear2meeDefaultSettings[Appear2mee.faceContentExtensionBackgroundImage]="face.png";
//appear2meeDefaultSettings[Appear2mee.fontentExtensionBackgroundImage]="media.jpg";

appear2meeDefaultSettings[Appear2mee.openExternalURLAutomatically] = 'true'

};

Appear2mee.configure(appear2meeDefaultSettings);
*/

class HomeScreen extends React.Component {
  static navigationOptions = {
    headerTitle: '2mee Demo',
  };

  constructor(props) {
    super(props);
    this.state = {
      senderId: appConfig.senderID,
    };

    this.state = {
      isDialogVisible: false,
      richMessagesSwitchValue: true,
      wifiOnlySwitchValue: false,
      messageServiceSwitchValue: true,
      playOnMuteSwitchValue: true,
    };
    Appear2mee.hasServicePermission(permission => {
      this.setState({messageServiceSwitchValue: permission});
    });
    Appear2mee.hasDownloadPermission(permission => {
      this.setState({richMessagesSwitchValue: permission});
    });
    Appear2mee.hasWifiOnlyPermission(permission => {
      this.setState({wifiOnlySwitchValue: permission});
    });
    Appear2mee.hasSoundOnMutePermission(permission => {
      this.setState({playOnMuteSwitchValue: permission});
    });
  }

  richMessagesToggleSwitch(value) {
    this.setState({richMessagesSwitchValue: value});
    Appear2mee.downloadPermission(value);
  }
  wifiOnlyToggleSwitch(value) {
    this.setState({wifiOnlySwitchValue: value});
    Appear2mee.wifiOnlyPermission(value);
  }
  messageServiceToggleSwitch(value) {
    this.setState({messageServiceSwitchValue: value});
    Appear2mee.servicePermission(value);
  }
  playOnMuteToggleSwitch(value) {
    this.setState({playOnMuteSwitchValue: value});
    Appear2mee.soundOnMutePermission(value);
  }

  showDialog(isShow) {
    this.setState({isDialogVisible: isShow});
  }
  sendInput(inputText) {
    console.log('sendInput (DialogInput#1): ' + inputText);
    Appear2mee.registerUserID(inputText);
  }


  render() {
    return (
      <SafeAreaView
        style={{flex: 1, alignItems: 'center', justifyContent: 'center'}}>
        <View
          style={{
            flex: 0.5,
            flexDirection: 'row',
            justifyContent: 'space-around',
            alignItems: 'center',
          }}
        />
        <View
          style={{
            flex: 1,
            flexDirection: 'row',
            justifyContent: 'space-around',
            alignItems: 'center',
          }}>
          <DialogInput
            dialogStyle={{marginBottom: 100}}
            isDialogVisible={this.state.isDialogVisible}
            title={'Enter UserID'}
            message={'The userID allows a link to CRM'}
            hintInput={'user10000'}
            submitInput={inputText => {
              this.sendInput(inputText);
              this.showDialog(false);
            }}
            closeDialog={() => {
              this.showDialog(false);
            }}
          />
          <Button
            title="Add UserID"
            onPress={() => {
              this.showDialog(true);
            }}
          />
          <View style={{padding: 10}} />
          <Button
            title="Change Tags"
            onPress={() => {
              /* 1. Navigate to the Tags route */
              this.props.navigation.navigate('Tags');
            }}
          />
        </View>
        <View
          style={{
            flex: 1,
            flexDirection: 'column',
            justifyContent: 'space-around',
            alignItems: 'center',
          }}>
          <Button
            title="Local Face Message Test"
            onPress={() => {
              Appear2mee.testFace();
            }}
          />
          <Button
            title="Local Rich Text Test"
            onPress={() => {
              Appear2mee.testRichText();
            }}
          />
        </View>
        <View
          style={{
            flex: 1,
            flexDirection: 'row',
            justifyContent: 'space-around',
            alignItems: 'center',
          }}
        />
        <Text style={{fontSize: 16, fontWeight: 'bold'}}>
          Message Download Permissions
        </Text>
        <View
          style={{
            flex: 1,
            flexDirection: 'column',
            justifyContent: 'space-around',
            alignItems: 'center',
          }}>

          <View
            style={{
              flex: 1,
              flexDirection: 'row',
              justifyContent: 'space-between',
              padding: 20,
            }}>
            <ToggleSwitch
              label="Rich Message"
              isOn={this.state.richMessagesSwitchValue}
              onToggle={value => {
                this.richMessagesToggleSwitch(value);
              }}
              labelStyle={{fontSize: 14, fontWeight: 'bold'}}
            />
            <ToggleSwitch
              label="Wifi Only"
              isOn={this.state.wifiOnlySwitchValue}
              labelStyle={{fontSize: 14, fontWeight: 'bold'}}
              onToggle={value => {
                this.wifiOnlyToggleSwitch(value);
              }}
            />
          </View>
          <View
            style={{
              flex: 1,
              flexDirection: 'row',
              justifyContent: 'space-between',
              padding: 20,
            }}>
            <ToggleSwitch
              label="Message Service"
              isOn={this.state.messageServiceSwitchValue}
              labelStyle={{fontSize: 14, fontWeight: 'bold'}}
              onToggle={value => {
                this.messageServiceToggleSwitch(value);
              }}
            />
            <View style={ {opacity: Platform.OS === 'ios' ? 100 : 0, margin:4}}>
              <ToggleSwitch
                label="Play on Mute"
                labelStyle={{fontSize: 14, fontWeight: 'bold'}}
                isOn={this.state.playOnMuteSwitchValue}
                onToggle={value => {
                  this.playOnMuteToggleSwitch(value);
                }}
              />
            </View>
          </View>
        </View>
        <View
          style={{
            flex: 0.5,
            flexDirection: 'row',
            justifyContent: 'space-around',
            alignItems: 'center',
          }}
        />
      </SafeAreaView>
    );
  }
}

const RootStack = createStackNavigator(
  {
    Home: {
      screen: HomeScreen,
    },
    Tags: {
      screen: TagsScreen,
    },
    AddTag: {
      screen: AddTagScreen,
    },
  },
  {
    headerLayoutPreset: 'center',
    initialRouteName: 'Home',
    defaultNavigationOptions: {
      headerStyle: {
        backgroundColor: '#f4511e',
      },
      headerTintColor: '#fff',
      headerTitleStyle: {},
    },
  },
);

const AppContainer = createAppContainer(RootStack);

export default class App extends React.Component {
  constructor(props) {
    super(props);
    this._handleToast = this._handleToast.bind(this);
  }

  splitOnFirst = (str, sep) => {
    var index = str.indexOf(sep);
    return index < 0 ? [str,""] : [str.slice(0, index), str.slice(index + sep.length)];
  }


  // Handle Toast Event
  _handleToast(message) {
    var messages = this.splitOnFirst(message, ":");
    Toast.show({
      type: 'success',text1: messages[0],
      text2: messages[1]
    });
  }

  componentDidMount() {
    DeviceEventEmitter.addListener('Toast', this._handleToast);
  }

  render() {
    return (
      <>
        <AppContainer />
         <Toast position='top'
        topOffset={60}
        />
      </>
    );
  }
}
