/**
 * Sample React Native App
 * https://github.com/facebook/react-native
 *
 * Modified to deal with notifications ... but lots of custom code/setup needed
 * See Appear2mee React Native Guide
 *
 * @format
 * @flow
 */

import React, {Fragment} from 'react';
import {
  SafeAreaView,
  StyleSheet,
  ScrollView,
  View,
  Text,
  Button,
  StatusBar,
} from 'react-native';

import {
  Header,
  LearnMoreLinks,
  Colors,
  DebugInstructions,
  ReloadInstructions,
} from 'react-native/Libraries/NewAppScreen';

// Access native code, and events
import {NativeEventEmitter, NativeModules} from 'react-native';
import PushNotification from 'react-native-push-notification';

var Appear2mee = NativeModules.RNAppear2mee;
const Appear2meeEmitter = new NativeEventEmitter(Appear2mee);
PushNotification.requestPermissions();

Appear2meeEmitter.addListener(Appear2mee.notificationAccepted, keyValues => {
  if (!keyValues) {
    keyValues = {};
  }
  console.log('Notification Accepted:' + JSON.stringify(keyValues), true);
});

Appear2meeEmitter.addListener(Appear2mee.notificationDismissed, keyValues => {
  if (!keyValues) {
    keyValues = {};
  }
  console.log('Notification Dismissed:' + JSON.stringify(keyValues), true);
});

export default class App extends React.Component {
  constructor(props) {
    super(props);
    // Notification service calls permisions in iOS ... see NotificationService.js if you want to call this later.
  }

  onRegister(token) {
    console.log(token);
  }

  // handles any notification not a Appear2mee notification
  onOtherNotif(notif) {
    console.log(notif);
  }

  // handles any notification response not a Appear2mee notification
  onOtherResponse(notif) {
    if (typeof notif.actionIdentifier !== 'undefined') {
      if (
        notif.actionIdentifier ===
        'com.apple.UNNotificationDefaultActionIdentifier'
      ) {
        // do actions
        console.log('other Notification:Action');
      }
      if (
        notif.actionIdentifier ===
        'com.apple.UNNotificationDismissActionIdentifier'
      ) {
        // do dismiss (note in iOS dismiss is only called is you are using a category and the user presses the dismiss option! )
        console.log('other Notification:Dismiss');
      }
    }
  }

  render() {
    return (
      <Fragment>
        <StatusBar barStyle="dark-content" />
        <SafeAreaView>
          <ScrollView
            contentInsetAdjustmentBehavior="automatic"
            style={styles.scrollView}>
            <Header />
            {global.HermesInternal == null ? null : (
              <View style={styles.engine}>
                <Text style={styles.footer}>Engine: Hermes</Text>
              </View>
            )}
            <Button
              title="Local Face Message Test"
              onPress={() => {
                Appear2mee.testFace();
              }}
            />
            <Button
              title="Local Rich Text Test"
              onPress={() => {
                Appear2mee.testRichText();
              }}
            />
            <View style={styles.body}>
              <View style={styles.sectionContainer}>
                <Text style={styles.sectionTitle}>Step One</Text>
                <Text style={styles.sectionDescription}>
                  Edit <Text style={styles.highlight}>App.js</Text> to change
                  this screen and then come back to see your edits.
                </Text>
              </View>
              <View style={styles.sectionContainer}>
                <Text style={styles.sectionTitle}>See Your Changes</Text>
                <Text style={styles.sectionDescription}>
                  <ReloadInstructions />
                </Text>
              </View>
              <View style={styles.sectionContainer}>
                <Text style={styles.sectionTitle}>Debug</Text>
                <Text style={styles.sectionDescription}>
                  <DebugInstructions />
                </Text>
              </View>
              <View style={styles.sectionContainer}>
                <Text style={styles.sectionTitle}>Learn More</Text>
                <Text style={styles.sectionDescription}>
                  Read the docs to discover what to do next:
                </Text>
              </View>
              <LearnMoreLinks />
            </View>
          </ScrollView>
        </SafeAreaView>
      </Fragment>
    );
  }
}

const styles = StyleSheet.create({
  scrollView: {
    backgroundColor: Colors.lighter,
  },
  engine: {
    position: 'absolute',
    right: 0,
  },
  body: {
    backgroundColor: Colors.white,
  },
  sectionContainer: {
    marginTop: 32,
    paddingHorizontal: 24,
  },
  sectionTitle: {
    fontSize: 24,
    fontWeight: '600',
    color: Colors.black,
  },
  sectionDescription: {
    marginTop: 8,
    fontSize: 18,
    fontWeight: '400',
    color: Colors.dark,
  },
  highlight: {
    fontWeight: '700',
  },
  footer: {
    color: Colors.dark,
    fontSize: 12,
    fontWeight: '600',
    padding: 4,
    paddingRight: 12,
    textAlign: 'right',
  },
});
