import React, {Component} from 'react';
import {
  FlatList,
  StyleSheet,
  Text,
  TouchableOpacity,
  TouchableHighlight,
  View,
  DeviceEventEmitter,
} from 'react-native';

import SwipeView from 'react-native-swipeview';
import {ListItem, Button} from 'react-native-elements';
import {SafeAreaView} from 'react-navigation';
import {HeaderBackButton} from 'react-navigation-stack';
import {NativeModules} from 'react-native';
var Appear2mee = NativeModules.RNAppear2mee;

const list = [];

export default class TagsScreen extends React.Component {
  static navigationOptions = ({navigation}) => {
    return {
      headerTintColor: '#fff',
      headerTitle: 'Tags',
      headerLeft: (
        <HeaderBackButton
          title="Save"
          tintColor="#fff"
          backTitleVisible={true}
          onPress={navigation.getParam('saveDetails')}
        />
      ),
      headerRight: (
        <Button
          title="Cancel"
          type="clear"
          titleStyle={{color: '#fff'}}
          onPress={() => {
            navigation.goBack();
          }}
        />
      ),
    };
  };

  // hack to allow a class method to be called in a static button function
  componentDidMount() {
    this.props.navigation.setParams({saveDetails: this._saveDetails});
    DeviceEventEmitter.emit('Toast', 'Swipe to delete');
  }

  _saveDetails = () => {
    // make a dict of list.
    var list = this.state.data;
    var tagsdict = {};
    var listLength = list.length;
    for (var i = 0; i < listLength; i++) {
      tagsdict[list[i].key] = list[i].value;
    }
    Appear2mee.registerTags(tagsdict);
    this.props.navigation.goBack();
  };

  constructor(props) {
    super(props);
    this.state = {data: list};
    Appear2mee.tags(tagsdict => {
      let tagslist = [];
      for (var key in tagsdict) {
        if (tagsdict.hasOwnProperty(key)) {
          tagslist.push({key: key, value: tagsdict[key]});
        }
      }
      this.setState({data: tagslist});
    });
  }

  returnData(key, value) {
    this.addItemById(key, value);
  }

  keyExtractor = (item, index) => index.toString();

  deleteItemById = key => {
    const filteredData = this.state.data.filter(item => item.key !== key);
    this.setState({data: filteredData});
  };

  addItemById = (newkey, newvalue) => {
    // need to make dictionary of list, then convert back to list after added new item!
    var list = this.state.data;
    var tagsdict = {};
    var listLength = list.length;
    for (var i = 0; i < listLength; i++) {
      tagsdict[list[i].key] = list[i].value;
    }
    tagsdict[newkey] = newvalue;

    let tagslist = [];
    for (var key in tagsdict) {
      if (tagsdict.hasOwnProperty(key)) {
        tagslist.push({key: key, value: tagsdict[key]});
      }
    }
    this.setState({data: tagslist});
  };

  renderItem = ({item}) => (
    <SwipeView
      disableSwipeToRight={false}
      renderVisibleContent={() => (
        <ListItem
          title={item.key}
          rightTitle={item.value}
          //leftAvatar={{ source: { uri: item.avatar_url } }}
          onPress={() =>
            this.props.navigation.navigate('AddTag', {
              itemKey: item.key,
              itemValue: item.value,
              returnData: this.returnData.bind(this),
            })
          }
        />
      )}
      renderRightView={() => (
        <View
          style={{
            flex: 1,
            justifyContent: 'flex-end',
            alignItems: 'center',
            backgroundColor: 'red',
          }}
        />
      )}
      leftOpenValue={this.leftOpenValue}
      rightOpenValue={this.rightOpenValue}
      //onSwipedLeft={() => alert("deleted")}
      onSwipedLeft={() => this.deleteItemById(item.key)}
      swipeDuration={300}
      swipeToOpenPercent={40}
      disableSwipeToRight={true}
    />
  );

  render() {
    const {navigation} = this.props;
    return (
      <SafeAreaView forceInset={{bottom: 'always'}} style={{flex: 1}}>
        <FlatList
          keyExtractor={this.keyExtractor}
          data={this.state.data}
          renderItem={this.renderItem}
        />
        <Button
          onPress={() =>
            navigation.navigate('AddTag', {
              returnData: this.returnData.bind(this),
            })
          }
          title="Add Tag"
        />
      </SafeAreaView>
    );
  }
}

var styles = StyleSheet.create({
  separator: {
    borderBottomColor: '#bbb',
    borderBottomWidth: StyleSheet.hairlineWidth,
  },
  headline: {
    textAlign: 'center', // <-- the magic
    fontWeight: 'bold',
    fontSize: 18,
    marginTop: 0,
  },
  container: {
    flex: 1,
    flexDirection: 'row',
    justifyContent: 'space-between',
  },
});
