//
//  NotificationService.m
//  serviceExtension
//
//  Created by Gerard Allan on 04/03/2021.
//

#import "NotificationService.h"

#import <Appear2mee/Appear2mee.h>
#import "../Appear2meeConstants.h"

@interface NotificationService ()
@property (nonatomic, strong) void (^contentHandler)(UNNotificationContent *contentToDeliver);
@property (nonatomic, strong) UNMutableNotificationContent *bestAttemptContent;
@property (nonatomic, strong) NSString *requestIdentifier;
@end

@implementation NotificationService

- (void)didReceiveNotificationRequest:(UNNotificationRequest *)request withContentHandler:(void (^)(UNNotificationContent * _Nonnull))contentHandler {

  self.contentHandler = contentHandler;
  self.bestAttemptContent = [request.content mutableCopy];
  self.requestIdentifier = request.identifier;
  
  if([Appear2mee handleAppear2meeNotificationContent:self.bestAttemptContent request:self.requestIdentifier withContentHandler:contentHandler usingAppGroup:APPGROUP]) {
    // Was an Appear2mee notification and has been handled.
    
  } else {
    // Modify the notification content here...
    //self.bestAttemptContent.title = [NSString stringWithFormat:@"%@ [modified]", self.bestAttemptContent.title];
    self.contentHandler(self.bestAttemptContent);
  }
}

- (void)serviceExtensionTimeWillExpire {
  // Called just before the extension will be terminated by the system.
  // Use this as an opportunity to deliver your "best attempt" at modified content, otherwise the original push payload will be used.
  
  [Appear2mee cancelDownloadForRequest:self.requestIdentifier]; // cancel any uncompleted tasks
  self.contentHandler(self.bestAttemptContent);
}


@end
